# CLI Reference

## Main commands

- `vyro run --app <module:attr>`
- `vyro dev --app <module:attr>`
- `vyro doctor [--strict]`
- `vyro openapi ...`
- `vyro compat ...`
- `vyro release ...`

## Exit codes

- `0`: success
- `1`: execution/tooling/runtime error
- `2`: validation/usage error
